Zymp
====

Zymp is a Python library to design "restriction site arrays", which are
compact sequences with many restriction sites.

For instance here is a 159-nucleotide sequence made with Zymp, with 49 enzyme
recognition sites (out of 52 provided). That's a frequency of around
3 nucleotides per site:

.. image:: https://raw.githubusercontent.com/Edinburgh-Genome-Foundry/zymp/master/docs/_static/images/example_array.png
   :width: 800

Infos
-----

**PIP installation:**

.. code:: bash

  pip install zymp

**Github page:** `<https://github.com/Edinburgh-Genome-Foundry/zymp>`_

**License:** MIT

Copyright 2018 Edinburgh Genome Foundry, University of Edinburgh


More biology software
---------------------

.. image:: https://raw.githubusercontent.com/Edinburgh-Genome-Foundry/Edinburgh-Genome-Foundry.github.io/master/static/imgs/logos/egf-codon-horizontal.png
  :target: https://edinburgh-genome-foundry.github.io/

Zymp is part of the `EGF Codons <https://edinburgh-genome-foundry.github.io/>`_
synthetic biology software suite for DNA design, manufacturing and validation.
